@@ -17,6 +17,7 @@ use File::Spec                   ( );
 use File::Spec::Functions      qw( curdir updir );
 use IO::Dir;
 use IO::File;
+use IO::Handle;
 use List::Util                 qw( first );
 use Scalar::Util               qw( blessed );
 use Sub::Install               qw( install_sub );
@@ -128,7 +129,7 @@ my $_is_one_of_us = sub {
 sub BUILDARGS { # Differentiate constructor method signatures
    my $class = shift; my $n = 0; $n++ while (defined $_[ $n ]);
 
-   return                 ( $n == 0 ) ? {}
+   return                 ( $n == 0 ) ? { io_handle => IO::Handle->new }
         : $_is_one_of_us->( $_[ 0 ] ) ? $_clone_one_of_us->( @_ )
         :       is_hashref( $_[ 0 ] ) ? { %{ $_[ 0 ] } }
         :                 ( $n == 1 ) ? { $_inline_args->( 1, @_ ) }
@@ -482,9 +483,7 @@ sub as_boolean {
 sub as_string {
    my $self = shift; CORE::length $self->name and return $self->name;
 
-   defined $self->io_handle and return NUL.$self->io_handle;
-
-   return NUL;
+   return defined $self->io_handle ? $self->io_handle.NUL : NUL;
 }
 
 sub assert {
@@ -645,8 +644,9 @@ sub clear {
 sub close {
    my $self = shift; $self->is_open or return $self;
 
-   # uncoverable branch true
-   if (is_ntfs) { $self->$_close_and_rename } else { $self->$_rename_and_close }
+   if (is_ntfs) { # uncoverable branch true
+      $self->$_close_and_rename; # uncoverable statement
+   } else { $self->$_rename_and_close }
 
    $self->_set_io_handle( undef );
    $self->_set_is_open  ( FALSE );
@@ -686,7 +686,7 @@ sub delete {
 }
 
 sub delete_tmp_files {
-   my ($self, $tmplt) = @_; $tmplt ||= '%6.6d....';
+   my ($self, $tmplt) = @_; $tmplt //= '%6.6d....';
 
    my $pat = sprintf $tmplt, $PID;
 
@@ -751,6 +751,17 @@ sub exists {
    return (CORE::length $_[ 0 ]->name && -e $_[ 0 ]->name) ? TRUE : FALSE;
 }
 
+sub fdopen {
+   my ($self, $fd, $mode) = @_;
+
+   $self->io_handle->fdopen( $fd, $mode );
+   $self->_set_is_open( $self->io_handle->opened );
+   $self->_set_mode( $mode );
+   $self->_set_name( NUL   );
+   $self->_set_type( undef );
+   return $self;
+}
+
 sub file {
    return shift->$_init( 'file', @_ );
 }
@@ -885,6 +896,9 @@ sub is_writing {
 sub iterator {
    my ($self, $args) = @_;
 
+   $self->is_dir
+      or $self->$_throw( "Path [_1] is not a directory", [ $self->name ] );
+
    my @dirs   = ( $self );
    my $filter = $self->_filter;
    my $deep   = $args->{recurse} // $self->_deep;
@@ -1097,9 +1111,7 @@ sub separator {
 sub set_binmode {
    my $self = shift;
 
-   if (is_ntfs) { # uncoverable branch true
-      is_member NUL, $self->_layers or unshift @{ $self->_layers }, NUL;
-   }
+   is_ntfs and $self->$_push_layer->(); # uncoverable branch true
 
    $self->$_sane_binmode( $_ ) for (@{ $self->_layers });
 
@@ -1151,9 +1163,9 @@ sub stat {
 }
 
 sub substitute {
-   my ($self, $search, $replace) = @_;
+   my ($self, $search, $replace) = @_; $replace //= NUL;
 
-   (defined $search and CORE::length $search) or return $self; $replace //= NUL;
+   (defined $search and CORE::length $search) or return $self;
 
    my $perms = $self->$_untainted_perms;
    my $wtr   = $self->$_constructor( $self->name )->atomic;
@@ -1749,6 +1761,12 @@ it L</throw>s an C<eIOError>
 
 Returns true if the pathname exists
 
+=head2 fdopen
+
+   $io = io()->fdopen( $fd, $mode );
+
+Opens the internal file handle on the supplied file descriptor
+
 =head2 file
 
 Initialises the current object as a file
@@ -2279,7 +2297,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
