@@ -43,7 +43,7 @@ my $_build_source_registrations = sub {
    for my $moniker (keys %{ $self->result_source_attributes }) {
       my $attr = { %{ $self->result_source_attributes->{ $moniker } } };
       my $class = delete $attr->{result_source_class}
-               || $self->result_source_class;
+               // $self->result_source_class;
 
       $attr->{name} = $moniker; $attr->{schema} = $self;
 
@@ -117,13 +117,14 @@ has 'tempdir'                  => is => 'ro',   isa => Directory,
 
 # Construction
 around 'BUILDARGS' => sub {
-   my ($orig, $class, @args) = @_; my $attr = $orig->( $class, @args );
+   my ($orig, $self, @args) = @_; my $attr = $orig->( $self, @args );
 
-   my $builder = delete $attr->{builder} or return $attr;
+   my $builder = $attr->{builder} or return $attr;
    my $config  = $builder->can( 'config' ) ? $builder->config : {};
+   my $keys    = [ qw( cache_attributes cache_class lock log tempdir ) ];
 
-   merge_attributes $attr, $builder, [ qw( lock log tempdir ) ];
-   merge_attributes $attr, $config,  [ qw( tempdir ) ];
+   merge_attributes $attr, $builder, $keys;
+   merge_attributes $attr, $config,  $keys;
 
    return $attr;
 };
@@ -167,7 +168,7 @@ sub sources {
 sub translate {
    my ($self, $args) = @_;
 
-   my $class      = blessed $self       || $self; # uncoverable condition false
+   my $class      = blessed $self || $self; # uncoverable condition false
    my $from_class = $args->{from_class} // 'Any';
    my $to_class   = $args->{to_class  } // 'Any';
    my $attr       = { path => $args->{from}, storage_class => $from_class };
@@ -392,7 +393,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
